[![Multi-Modality](agorabanner.png)](https://discord.gg/qUtxnK2NMf)

# Quasar
Quasar: Mistral, mastering mathematical reasoning.
![Quasar](/quasar.jpeg)

## Features:
- Mistral7b finetuned on high quality tokens for stellar mathematical reasoning.
- Mistral7b extended to 16k seq and soon 32k and then 65k!
- High Quality reasoning for all reasoning intensive tasks.

## Architecture


## Install

## Usage

## License
MIT